/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNfi for the 3D integration at all eps-orders of the pseudo-nf structure. 
 * Example: PNfI3EM2 ('P'seudo-'Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XPNf functions to arrive at eps^-2. 
 * Starting from eps^-3 (3 deltas) we need 1 eps power, which we get from XPNf1 (which comes with eps^1) and no Logs, or Log^1 terms multiplied with XPNf0 (eps^1 from the logs)
 */

#include <Auxiliaries.h>
#include <3IntPNF.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>


double PNfI3EM3(double w,double s6,double c) {
	return (pow(mexp,-1)*pow(n,-1)*XPNf0(w,s6,0,0,c))/4.;
}

double PNfI3EM2(double w,double s6,double c) {
	return (pow(mexp,-1)*pow(n,-1)*((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf0(w,s6,0,0,c) +
		       XPNf1(w,s6,0,0,c)))/4.;
}

double PNfI3EM1(double w,double s6,double c) {
	return (pow(mexp,-1)*pow(n,-1)*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) +
	          pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf0(w,s6,0,0,c) + (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) +
	          log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf1(w,s6,0,0,c) + XPNf2(w,s6,0,0,c)))/4.;
}

double PNfI3E0(double w,double s6,double c) {
	return (pow(mexp,-1)*pow(n,-1)*(8*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) +
	          pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*XPNf0(w,s6,0,0,c) + 3*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) +
	             pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf1(w,s6,0,0,c) +
	          (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf2(w,s6,0,0,c) + XPNf3(w,s6,0,0,c))))/
	   12.;
}


