/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEi for the 2D integration at all eps-orders of the Cf^2 structure, subregion a. 
 * Example: I2EM2 ('I'ntegration over '2' dimensions, at 'E'ps to the 'M'inus '2'nd order) contains various logs of FXi functions
 * evaluated at x=0,r=0,c=0,s5=0, i.e. with all the deltas from +-distributions, multiplied with the correct X functions' eps-powers to arrive at eps^-2. 
 */

#include <2Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I2EM4(double s, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*XCfE0(s,0,s6))/4.;
}

double I2EM3(double s, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*((log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
	          log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) + XCfE1(0,0,s,0,s6)))/4.;
}

double I2EM2(double s, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE0(s,0,s6) +
	       (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
	        XCfE1(0,0,s,0,s6) + XCfE2(0,0,s,0,s6)))/4.;
}

double I2EM1(double s, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*(8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3))*XCfE0(s,0,s6) +
	       3*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
	             pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE1(0,0,s,0,s6) +
	          (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
	           XCfE2(0,0,s,0,s6) + XCfE3(0,0,s,0,s6))))/12.;
}

double I2E0(double s, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*(8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),4) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),4) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),4) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),4))*XCfE0(s,0,s6) +
	       8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3))*XCfE1(0,0,s,0,s6) +
	       3*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
	             pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE2(0,0,s,0,s6) +
	          (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*
	           XCfE3(0,0,s,0,s6) + XCfE4(0,0,s,0,s6))))/12.;
}
