/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 4D integration at all eps-orders and the alpha^-1 order of the Rest-CA structure. 
 * Example: CAI4EP1AM1sz ('CA' structure, 'I'ntegration over '4' dimensions, at 'E'ps to the 'P'lus '1'st and 'A'lpha to the 'M'inus '1'st order, third and fourth integration over 's'5 and 'z') 
 * contains various differences of logs of FXi functions evaluated at c=0,x=0, i.e. with deltas from all +-distributions except the t5/s5 and u/z ones, multiplied 
 * with the correct XCA functions to arrive at eps^1 alpha^-1. 
 */

#include <4IntCAAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

//third and forth integration over x, s5 not present, no 1/alpha with x

//third and forth integration over x, z not present, no 1/alpha with x

//third and forth integration over x, c not present, no 1/alpha with x

//third and forth integration over s5, z

double CAI4EM1AM1sz(double w,double s6,double s5,double z) {
	return pow(s5,-1)*pow(z,-1)*(-XCA00(w,s6,0,0,0) + XCA00(w,s6,0,z,0) + XCA00(w,s6,s5,0,0) - XCA00(w,s6,s5,z,0));
}

double CAI4E0AM1sz(double w,double s6,double s5,double z) {
	return pow(s5,-1)*pow(z,-1)*((2*log(s5) + 4*log(z) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + 
     (-2*log(s5) - 4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)))*XCA00(w,s6,0,z,0) - 
     2*log(s5)*XCA00(w,s6,s5,0,0) - 4*log(z)*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*
        FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + 2*log(s5)*XCA00(w,s6,s5,z,0) + 4*log(z)*XCA00(w,s6,s5,z,0) - 
     log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) - XCA01(w,s6,0,0,0) + 
     XCA01(w,s6,0,z,0) + XCA01(w,s6,s5,0,0) - XCA01(w,s6,s5,z,0));
}

double CAI4EP1AM1sz(double w,double s6,double s5,double z) {
	return pow(s5,-1)*pow(z,-1)*(-2*(log(s5)*(4*log(z) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + pow(log(s5),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) + 
     2*(log(s5)*(4*log(z) - log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)) + pow(log(s5),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*
      XCA00(w,s6,0,z,0) + 2*(log(s5)*(4*log(z) - log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0)) + pow(log(s5),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*
      XCA00(w,s6,s5,0,0) - 2*(log(s5)*(4*log(z) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0)) + pow(log(s5),2) + 
        4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),u(z),0)),2) + 
        pow(log(FB2(v(w),tl(s6),0,t5(s5),u(z),0)),2))*XCA00(w,s6,s5,z,0) + (2*log(s5) + 4*log(z) - 
        log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA01(w,s6,0,0,0) + 
     (-2*log(s5) - 4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)))*XCA01(w,s6,0,z,0) + 
     (-2*log(s5) - 4*log(z) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA01(w,s6,s5,0,0) + 
     (2*log(s5) + 4*log(z) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0)))*XCA01(w,s6,s5,z,0) - 
     XCA02(w,s6,0,0,0) + XCA02(w,s6,0,z,0) + XCA02(w,s6,s5,0,0) - XCA02(w,s6,s5,z,0));
}


//third and forth integration over s5, c

double CAI4EM1AM1sc(double w,double s6,double s5,double c) {
	return pow(c,-1)*pow(s5,-1)*(-XCA00(w,s6,0,0,0) + XCA00(w,s6,0,0,c) + XCA00(w,s6,s5,0,0) - XCA00(w,s6,s5,0,c));
}

double CAI4E0AM1sc(double w,double s6,double s5,double c) {
	return pow(c,-1)*pow(s5,-1)*((4*log(c) + 2*log(s5) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + 
     (-4*log(c) - 2*log(s5) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XCA00(w,s6,0,0,c) - 
     4*log(c)*XCA00(w,s6,s5,0,0) - 2*log(s5)*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*
        FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + 4*log(c)*XCA00(w,s6,s5,0,c) + 2*log(s5)*XCA00(w,s6,s5,0,c) - 
     log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - XCA01(w,s6,0,0,0) + 
     XCA01(w,s6,0,0,c) + XCA01(w,s6,s5,0,0) - XCA01(w,s6,s5,0,c));
}

double CAI4EP1AM1sc(double w,double s6,double s5,double c) {
	return pow(c,-1)*pow(s5,-1)*(-2*(log(c)*(4*log(s5) - 2*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))) - 
        log(s5)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + 4*pow(log(c),2) + pow(log(s5),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) + 
     2*(log(c)*(4*log(s5) - 2*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))) - 
        log(s5)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 4*pow(log(c),2) + pow(log(s5),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
      XCA00(w,s6,0,0,c) + 2*(log(c)*(4*log(s5) - 2*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))) - 
        log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0)) + 4*pow(log(c),2) + pow(log(s5),2) + 
        pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*
      XCA00(w,s6,s5,0,0) - 2*(log(c)*(4*log(s5) - 2*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*
              FB2(v(w),tl(s6),0,t5(s5),0,b(c)))) - log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*
           FB2(v(w),tl(s6),0,t5(s5),0,b(c))) + 4*pow(log(c),2) + pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))),2) + 
        pow(log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))),2))*XCA00(w,s6,s5,0,c) + 
     (4*log(c) + 2*log(s5) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA01(w,s6,0,0,0) + 
     (-4*log(c) - 2*log(s5) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XCA01(w,s6,0,0,c) + 
     (-4*log(c) - 2*log(s5) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA01(w,s6,s5,0,0) + 
     (4*log(c) + 2*log(s5) - log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))))*XCA01(w,s6,s5,0,c) - 
     XCA02(w,s6,0,0,0) + XCA02(w,s6,0,0,c) + XCA02(w,s6,s5,0,0) - XCA02(w,s6,s5,0,c));
}


//third and forth integration over z, c

double CAI4EM1AM1zc(double w,double s6,double z,double c) {
	return -2*pow(c,-1)*pow(z,-1)*(XCA00(w,s6,0,0,0) - XCA00(w,s6,0,0,c) - XCA00(w,s6,0,z,0) + XCA00(w,s6,0,z,c));
}

double CAI4E0AM1zc(double w,double s6,double z,double c) {
	return 2*pow(c,-1)*pow(z,-1)*((4*log(c*z) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + 
     (-4*log(c*z) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XCA00(w,s6,0,0,c) - 4*log(c*z)*XCA00(w,s6,0,z,0) + 
     log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + 4*log(c*z)*XCA00(w,s6,0,z,c) - 
     log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - XCA01(w,s6,0,0,0) + 
     XCA01(w,s6,0,0,c) + XCA01(w,s6,0,z,0) - XCA01(w,s6,0,z,c));
}

double CAI4EP1AM1zc(double w,double s6,double z,double c) {
	return 2*pow(c,-1)*pow(z,-1)*(-2*(log(c)*(8*log(z) - 2*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + 4*pow(log(c),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) + 
     2*(log(c)*(8*log(z) - 2*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 4*pow(log(c),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
      XCA00(w,s6,0,0,c) + 2*(log(c)*(8*log(z) - 2*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)) + 4*pow(log(c),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*
      XCA00(w,s6,0,z,0) - 2*(log(c)*(8*log(z) - 2*log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))) - 
        2*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c))) + 4*pow(log(c),2) + 4*pow(log(z),2) + 
        pow(log(FA1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),b(c))),2))*
      XCA00(w,s6,0,z,c) + (4*log(c*z) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA01(w,s6,0,0,0) - 
     (4*log(c*z) - log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XCA01(w,s6,0,0,c) - 
     (4*log(c*z) - log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)))*XCA01(w,s6,0,z,0) + 
     (4*log(c*z) - log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c))))*XCA01(w,s6,0,z,c) - XCA02(w,s6,0,0,0) + 
     XCA02(w,s6,0,0,c) + XCA02(w,s6,0,z,0) - XCA02(w,s6,0,z,c));
}
