/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 2D integration at all eps-orders and the alpha^0 order of the Rest-CA structure. 
 * Example: CAI2EM2 ('CA' structure, 'I'ntegration over '2' dimensions, at 'E'ps to the 'M'inus '2'nd and alpha^0 order) contains various logs of FXi functions 
 * evaluated at z=0,c=0,x=0,s5=0, i.e. with all the deltas from +-distributions, multiplied with the correct XCA functions to arrive at eps^-2 alpha^0. 
 */

#include <2IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

using namespace std;

double CAI2EM4(double w, double s6) {
	return 0.;
}

double CAI2EM3(double w,double s6) {
	return -((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0))/16.;
}

double CAI2EM2(double w,double s6) {
	return (-4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
     (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0))/16.;
}

double CAI2EM1(double w,double s6) {
	return (-8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA0(w,s6,0,0,0) - 
     4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) - 
     (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA2(w,s6,0,0,0))/16.;
}

double CAI2E0(double w,double s6) {
	return (-32*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),4) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),4) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),4) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),4))*XCA0(w,s6,0,0,0) - 
     3*(8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA1(w,s6,0,0,0) + 
        4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA2(w,s6,0,0,0) + 
        (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA3(w,s6,0,0,0)))/48.;
}
