/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 2D integration at all eps-orders and alpha^-1 order of the Cf^2 structure, subregion b.
 * Example: I2EM2AM1 ('I'ntegration over '2' dimensions, at 'E'ps to the 'M'inus '2'nd and 'A'lpha to the 'M'inus '1'st order) contains various logs of FXi functions
 * evaluated at xk=0,xl=0,c=0,s5=0, i.e. with all the deltas from +-distributions, multiplied with the correct X functions' eps- and alpha-powers to arrive at 
 * eps^-2 alpha^-1. 
 */

#include <2IntAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I2EM3AM1(double s,double s6) {
	return -(pow(mexp,-2)*XCfE0A0(s,0,s6))/2.;
}

double I2EM2AM1(double s,double s6) {
	return -(pow(mexp,-2)*(-2*XCfE0A1(0,0,s,0,s6) + XCfE1A0(0,0,s,0,s6)))/2.;
}

double I2EM1AM1(double s,double s6) {
	return (pow(mexp,-2)*(4*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) + 4*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE0A1(0,0,s,0,s6) +
		       2*XCfE1A1(0,0,s,0,s6) - XCfE2A0(0,0,s,0,s6)))/2.;
}

double I2E0AM1(double s,double s6) {
	return (pow(mexp,-2)*(32*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3))*XCfE0A0(s,0,s6) +
		       6*(2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2))*(2*XCfE0A1(0,0,s,0,s6) + XCfE1A0(0,0,s,0,s6)) +
		          2*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1A1(0,0,s,0,s6) + XCfE2A1(0,0,s,0,s6)) - 3*XCfE3A0(0,0,s,0,s6)))/6.;
}

double I2E1AM1(double s,double s6) {
	return (pow(mexp,-2)*(48*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),4) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),4))*XCfE0A0(s,0,s6) +
		       4*(8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3))*XCfE0A1(0,0,s,0,s6) + 8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3))*XCfE1A0(0,0,s,0,s6) +
		          3*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2))*(2*XCfE1A1(0,0,s,0,s6) + XCfE2A0(0,0,s,0,s6)) +
		          3*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE2A1(0,0,s,0,s6)) + 6*XCfE3A1(0,0,s,0,s6) - 3*XCfE4A0(0,0,s,0,s6)))/6.;
}
