/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 4D integration at all eps-orders and the alpha^-2 order of the Cf^2 structure, subregion b. 
 * Example: I4E0AM2kl ('I'ntegration over '4' dimensions, at 'E'ps to the '0'th and 'A'lpha to the 'M'inus '2'nd order, third and fourth integrations over 
 * x'k' and x'l') contains various logs of FXi functions evaluated at c=0,s5=0, i.e. with the two deltas from the c and s5 +-distributions, multiplied 
 * with the correct X functions' eps- and alpha-powers to arrive at eps^0 alpha^-2. 
 */

#include <4IntAM2.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

//need both alpha poles
double I4E0AM2kl(double xk, double xl, double s, double s6) {
	return 0;
}
double I4E1AM2kl(double xk, double xl, double s, double s6) {
	return 0;
}
double I4E2AM2kl(double xk, double xl, double s, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2kc(double c, double xk, double s, double s6) {
	return 0;
}
double I4E1AM2kc(double c, double xk, double s, double s6) {
	return 0;
}
double I4E2AM2kc(double c, double xk, double s, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2ks(double xk, double s, double s5, double s6) {
	return 0;
}
double I4E1AM2ks(double xk, double s, double s5, double s6) {
	return 0;
}
double I4E2AM2ks(double xk, double s, double s5, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2lc(double c, double xl, double s, double s6) {
	return 0;
}
double I4E1AM2lc(double c, double xl, double s, double s6) {
	return 0;
}
double I4E2AM2lc(double c, double xl, double s, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2ls(double xl, double s, double s5, double s6) {
	return 0;
}
double I4E1AM2ls(double xl, double s, double s5, double s6) {
	return 0;
}
double I4E2AM2ls(double xl, double s, double s5, double s6) {
	return 0;
}

double I4E0AM2cs(double c, double s, double s5, double s6) {
	return 0; //2 alpha poles, rest leading order
}
double I4E1AM2cs(double c, double s, double s5, double s6) {
	return 16*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
		     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}
double I4E2AM2cs(double c, double s, double s5, double s6) {
	return 16*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*(-2*(-(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2)*XCfE0A0(s,0,s6)) + pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2)*XCfE0A0(s,0,s6) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)*XCfE0A0(s,0,s6) +
	        pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2)*XCfE0A0(s,0,s6) + pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2)*XCfE0A0(s,s5,s6) - pow(log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))),2)*XCfE0A0(s,s5,s6) +
	        pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)*XCfE0A0(s,s5,s6) - pow(log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))),2)*XCfE0A0(s,s5,s6) +
	        (2*log(c) + log(s5))*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	           (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6))) +
	     (log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE1A0(0,0,s,0,s6) +
	     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE1A0(0,0,s,s5,s6));
}
