/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 5D integration at all eps-orders and the alpha^0 order of the Cf^2 structure, subregion b. 
 * Example: I5EM1A0s ('I'ntegration over '5' dimensions, at 'E'ps to the 'M'inus '1'st and 'A'lpha to the '0'th order, only missing integration over 's'5) 
 * contains various logs of FXi functions evaluated at s5=0, i.e. with only the delta from the s5 +-distribution, multiplied with the correct X functions' 
 * eps- and alpha-powers to arrive at eps^-1 alpha^0. 
 */

#include <5Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I5EM1A0k(double c, double xl, double s, double s5, double s6) {
	return 0; //alpha pole present, leading order xl-indep
}
double I5E0A0k(double c, double xl, double s, double s5, double s6) {
	return -4*pow(c,-1)*pow(mexp,-1)*pow(s5,-1)*pow(xl,-1)*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))) +
	        log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}

double I5EM1A0l(double c, double xk, double s, double s5, double s6) {
	return 0; //alpha pole present, leading order xk-indep
}
double I5E0A0l(double c, double xk, double s, double s5, double s6) {
	return -4*pow(c,-1)*pow(mexp,-1)*pow(s5,-1)*pow(xk,-1)*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))) +
	        log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)) - log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0)) - log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}

double I5EM1A0c(double xk, double xl, double s, double s5, double s6) {
	return 0; //leading order is xi-indep
}
double I5E0A0c(double xk, double xl, double s, double s5, double s6) {
	return (pow(s5,-1)*pow(xk,-1)*pow(xl,-1)*(2*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),yl(xl),t(s),0,tl(s6),0)) +
	          log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,yl(xl),t(s),0,tl(s6),0)) - log(FB2(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),yl(xl),t(s),0,tl(s6),0)))*XCfE0A0(s,0,s6) -
	       2*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)) + log(FB1(yk(xk),yl(xl),t(s),t5(s5),tl(s6),0)) +
	          log(FB2(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0)) + log(FB2(yk(xk),yl(xl),t(s),t5(s5),tl(s6),0)))*XCfE0A0(s,s5,s6) +
	       XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6) - XCfE1A0(0,xl,s,0,s6) + XCfE1A0(0,xl,s,s5,s6) - XCfE1A0(xk,0,s,0,s6) + XCfE1A0(xk,0,s,s5,s6) + XCfE1A0(xk,xl,s,0,s6) - XCfE1A0(xk,xl,s,s5,s6)))/2.;
}

double I5EM1A0s(double c, double xk, double xl, double s, double s6) {
	return 0; //eps pole present, all other orders at leading -> vanishes
}
double I5E0A0s(double c, double xk, double xl, double s, double s6) {
	return 2*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) +
		     log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))) + log(FB1(yk(xk),yl(xl),t(s),0,tl(s6),0)) - log(FB1(yk(xk),yl(xl),t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) -
		     log(FB2(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),b(c))) - log(FB2(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),b(c))) + log(FB2(yk(xk),yl(xl),t(s),0,tl(s6),0)) -
		     log(FB2(yk(xk),yl(xl),t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(xk,-1)*pow(xl,-1)*XCfE0A0(s,0,s6);
}
